@@ -5,14 +5,13 @@
 # License: MIT
 
 import argparse
-import sys
 import logging
+import sys
 import traceback
 
-from .log import CustomLogFormatter
-from .ffmpeg_quality_metrics import FfmpegQualityMetrics, VmafOptions
-
 from .__init__ import __version__ as version
+from .ffmpeg_quality_metrics import FfmpegQualityMetrics, VmafOptions
+from .log import CustomLogFormatter
 
 logger = logging.getLogger("ffmpeg-quality-metrics")
 
@@ -31,7 +30,7 @@ def setup_logger(level: int = logging.INFO) -> logging.Logger:
     return logger
 
 
-def main():
+def main() -> None:
     parser = argparse.ArgumentParser(
         formatter_class=lambda prog: argparse.ArgumentDefaultsHelpFormatter(
             prog, max_help_position=40, width=100
@@ -169,6 +168,7 @@ def main():
         verbose=cli_args.verbose,
         threads=cli_args.threads,
         progress=cli_args.progress,
+        keep_tmp_files=cli_args.keep_tmp,
     )
 
     metrics = cli_args.metrics
